#
# spec file for package python-python-sql
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-python-sql
Version:        1.5.2
Release:        1.2
Summary:        Library to write SQL queries
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://pypi.io/project/python-sql
## Source:         https://pypi.io/packages/source/p/python-sql/python-sql-%%{version}.tar.gz
## Naming scheme broken upsream
Source:         https://files.pythonhosted.org/packages/source/p/python_sql/python_sql-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
python-sql is a library to write SQL queries in a pythonic way.

%prep
%autosetup -n python_sql-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
mv sql sql_hide
%pyunittest discover -v
mv sql_hide sql

%files %{python_files}
%license COPYRIGHT
%doc README.rst
%{python_sitelib}/sql
%{python_sitelib}/python_sql-%{version}.dist-info

%changelog
* Thu Oct 31 2024 Dirk Müller <dmueller@suse.com>
- update to 1.5.2:
  * Use parameter for unary operator
  * Support default values when inserting not matched merge
  * Replace assert by ValueError
* Thu Jun  6 2024 Dirk Müller <dmueller@suse.com>
- update to 1.5.1:
  * Use parameter for start and end of WINDOW FRAME
  * Use parameter for limit and offset
* Mon May 20 2024 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file.
* Wed May 15 2024 Axel Braun <axel.braun@gmx.de>
- version 1.5.0
  * naming scheme broken upstream
  * Add MERGE query
  * Support “UPSERT” with ON CONFLICT clause on INSERT query
  * Remove default escape char on LIKE and ILIKE
  * Add GROUPING SETS, CUBE, and ROLLUP clauses for GROUP BY.
* Sat Jan 13 2024 Axel Braun <axel.braun@gmx.de>
- added %%{?sle15_python_module_pythons}
* Tue Jan  9 2024 Dirk Müller <dmueller@suse.com>
- update to 1.4.3:
  * Render common table expression in combining query
  * Add support for Python 3.12
  * Restore usage of alias in returning expression
  * Do not use alias in returning expression
* Tue May  3 2022 Axel Braun <axel.braun@gmx.de>
- version 1.4.0
  * Use unittest discover
  * Use only column name for INSERT and UPDATE
  * Add escape to Like operators
  * Add default literal ‘*’ expression to Count
  * Add support for Python 3.10
* Tue Sep 14 2021 Axel Braun <axel.braun@gmx.de>
- Version 1.3.0
  * Add GROUPS frame to Window
  * Add exclude to Window
  * Add method for each type of join
  * Remove support for Python older than 3.5
  * Support Select queries in conditionals and functions
* Fri Sep 10 2021 pgajdos@suse.com
- version update to 1.2.2
  Version 1.2.2 - 2021-05-16
  * Escape table and column names containing double quote
  * Use alias on the main table used in UPDATE and INSERT
  * Add support for Python 3.9
  Version 1.2.1 - 2020-10-08
  * Fix AttributeError in Select.params with windows
* Tue Oct  6 2020 Axel Braun <axel.braun@gmx.de>
- Version 1.2.0
  * Add explicit Windows to Select
  * Fix missing Windows definitions in nested expressions
* Sat Jan 25 2020 Axel Braun <axel.braun@gmx.de>
- Version 1.1.0 - 2020-01-25
  * Add ORDER BY clause to aggregate functions
  * Add support for Python 3.8
  * Add distinct on Select
* Mon Oct  1 2018 Axel Braun <axel.braun@gmx.de>
- Version 1.0.0
  * Add Flavor filter_ to fallback to case expression
  * Allow to use expression in AtTimeZone
  * Add comparison predicates
  * Add COLLATE
  * various bugfixes
* Mon Apr 24 2017 axel.braun@gmx.de
- Version 0.9
  * Add distinct_on on Select
  * Allow to use Select as Column of Select query
  * Support Select without from clause
* Mon Apr 17 2017 axel.braun@gmx.de
- singlespec
  source URL corrected
* Thu Jun 30 2016 axel.braun@gmx.de
- corrected name/metaname
* Thu Jun 30 2016 axel.braun@gmx.de
- correct naming to python-python-sql
  correct License
* Sat Sep 19 2015 axel.braun@gmx.de
- Version 0.8
  * Add DISTINCT qualifier to aggregate expressions
  * Allow to order on select queries
  * Add NULL ordering
  * Use UPPER to simulate missing ILIKE
  * Add CURRENT_DATE function
  * Fix DateTrunc function name
  * Add no_boolean Flavor
  * Add converter format2numeric
  * Add rownum limit style
  * Add no_as Flavor
* Wed May 20 2015 axel.braun@gmx.de
- upgrade to version 0.7
  * Fix WINDOW and HAVING params order in Select
  * Add window functions
  * Add filter and within group to aggregate
  * Add limitstyle with 'offset' and 'limit'
  * Add Lateral
* Fri Feb  6 2015 axel.braun@gmx.de
- upgrade to version 0.6
  * Fix Delete query under multithread
  * Add missing quote for with query name
- Changes from version 0.5
  * Add schema
  * Add Common Table Expression
  * Escape Mod operator '%%' with format paramstyle
  * Deprecate Interesect in favor of Intersect
  * Add Values
- remove build dependencies to python-Genshi, python-lxml
* Fri Sep 12 2014 axel.braun@gmx.de
- upgrade to version 0.4
* Mon Mar 24 2014 axel.braun@gmx.de
- update to version 0.3
* Mon Oct 28 2013 axel.braun@gmx.de
- Initial Build on OBS
